==> HostCMS.Free_6.7.tar.gz: modules/shop/purchase/discount/coupon/i18n/en.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @subpackage Shop
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Discount coupon',
	'list_of_coupons' => 'Discount coupons',
	'coupon' => 'Discount coupon',
	'coupon_add' => 'Add',
	'not_enough_discounts' => 'Please add at least 1 purchase discount!',
	'coupon_form_table_title_add' => 'Add discount coupon',
	'coupon_form_table_title_edit' => 'Edit discount coupon',
	'name' => '<acronym title="Name of discount coupon">Name</acronym>',
	'shop_purchase_discount_id' => '<acronym title="Discount granted by discount coupon">Discount</acronym>',
	'active' => '<acronym title="Discount coupon activity">Activity</acronym>',
	'start_datetime' => "<acronym title=\"Validity start date of discount\">Valid from</acronym>",
	'end_datetime' => "<acronym title=\"Validity end date of discount\">Valid to</acronym>",
	'count' => '<acronym title="Number of coupon, -1 &mdash; unlimited">Number</acronym>',
	'text' => '<acronym title="Code to be entered by customer to get a discount by discount coupon. You can substitute it by a text-numeric value, e.g. \'DISCOUNT-2008\' or \'Christmas\'">Discount coupon code</acronym>',
	'changeStatus_success' => "Information updated successfully",
	'markDeleted_success' => 'Discount coupon information deleted successfully!',
	'edit_success' => 'Discount coupon information added successfully.',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'id' => 'Id',
	'import' => 'Import',
	'import_form' => 'File',
	'import_result' => '%s coupons were imported!',
	'import_error' => 'An error has occured: %s',
);

==> HostCMS.Free_7.0.tar.gz: modules/shop/purchase/discount/coupon/i18n/en.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @subpackage Shop
 * @version 7.x
 * @author Hostmake LLC
 * @copyright © 2005-2022 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Discount coupon',
	'list_of_coupons' => 'Discount coupons',
	'coupon' => 'Discount coupon',
	'coupon_add' => 'Add',
	'not_enough_discounts' => 'Please add at least 1 purchase discount!',
	'coupon_form_table_title_add' => 'Add discount coupon',
	'coupon_form_table_title_edit' => 'Edit discount coupon',
	'name' => 'Name',
	'shop_purchase_discount_id' => 'Discount',
	'active' => 'Active',
	'start_datetime' => "Valid from",
	'end_datetime' => "Valid to",
	'count' => '<acronym title="Number of coupon, -1 &mdash; unlimited">Number</acronym>',
	'text' => '<acronym title="Code to be entered by customer to get a discount by discount coupon. You can substitute it by a text-numeric value, e.g. \'DISCOUNT-2008\' or \'Christmas\'">Discount coupon code</acronym>',
	'changeStatus_success' => "Information updated successfully",
	'markDeleted_success' => 'Discount coupon information deleted successfully!',
	'edit_success' => 'Discount coupon information added successfully.',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'id' => 'ID',
	'import' => 'Import',
	'import_form' => 'File',
	'import_result' => '%s coupons were imported!',
	'import_error' => 'An error has occured: %s',
	'shop_order_id' => 'Order',
	'apply_success' => "Information changed successfully.",
	'copy_success' => "Item copied successfully!",
	'sorting' => "Sort order",
	'shop_purchase_discount_coupon_dir_id' => 'Section',
	'root' => "Root",
	'move_dirs_title' => "Move sections and items",
	'move_items_dirs' => "Parent section",
	'move_success' => 'Discounts moved',
);
